@@ -49,11 +49,15 @@ class MutationErrorHandler:
     def parse_error(cls, error):
         if isinstance(error, ValidationError):
             errors = []
-            for field, validation_errors in error.error_dict.items():
-                messages = []
-                for e in validation_errors:
-                    messages.append(*e.messages)
-                errors.append(cls.to_type_dict(field, messages))
+            if hasattr(error, 'error_dict'):
+                for field, validation_errors in error.error_dict.items():
+                    messages = []
+                    for e in validation_errors:
+                        messages.append(*e.messages)
+                    errors.append(cls.to_type_dict(field, messages))
+            if hasattr(error, 'error_list'):
+                for err in error.error_list:
+                    errors.append(cls.to_type_dict("object", [err.message]))
             return errors
         if isinstance(error, MutationError):
             return [cls.to_type_dict(error.field, error.message_list)]
